@@ -6,6 +6,8 @@ alignments = {
     'right': Qt.AlignRight,
     'top': Qt.AlignTop,
     'bot': Qt.AlignBottom,
+    'bottom': Qt.AlignBottom,
+    'center': Qt.AlignCenter,
 }
 
 
@@ -91,20 +93,4 @@ class CHBoxLayout(ContextLayout, QHBoxLayout):
 
 
 class CGridLayout(ContextLayout, QGridLayout):
-    pass
-
-
-class VLine(QFrame):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.setFrameShape(QFrame.VLine)
-        self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Expanding)
-        self.setLineWidth(1)
-
-
-class HLine(QFrame):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.setFrameShape(QFrame.HLine)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        self.setLineWidth(1)
\ No newline at end of file
+    pass
\ No newline at end of file
